==> 20251025-014506-1761381906-17.0.21.2-1076834798.tar.gz: files/tmp/callaccounting_dump/callaccounting.sql <==
/*M!999999\- enable the sandbox mode */ 
-- MariaDB dump 10.19  Distrib 10.11.14-MariaDB, for debian-linux-gnu (x86_64)
--
-- Host: localhost    Database: asterisk
-- ------------------------------------------------------
-- Server version	10.11.14-MariaDB-0+deb12u2

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `callaccounting_ratedeck`
--

DROP TABLE IF EXISTS `callaccounting_ratedeck`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `callaccounting_ratedeck` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(30) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `index1` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `callaccounting_ratedeck`
--

LOCK TABLES `callaccounting_ratedeck` WRITE;
/*!40000 ALTER TABLE `callaccounting_ratedeck` DISABLE KEYS */;
/*!40000 ALTER TABLE `callaccounting_ratedeck` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `callaccounting_rate_patterns`
--

DROP TABLE IF EXISTS `callaccounting_rate_patterns`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `callaccounting_rate_patterns` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `rate_deck_id` int(11) NOT NULL,
  `dial_pattern` varchar(32) NOT NULL,
  `initial_cost` decimal(5,2) NOT NULL,
  `initial_time` varchar(5) NOT NULL DEFAULT '0',
  `cost_per_increment` decimal(5,2) NOT NULL,
  `increment_time` varchar(5) NOT NULL DEFAULT '60',
  `tagname` varchar(50) DEFAULT NULL,
  `timegroup` int(11) DEFAULT NULL,
  `call_direction` varchar(255) DEFAULT 'Outbound',
  `add_time` datetime NOT NULL,
  `update_time` datetime NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `index1` (`rate_deck_id`,`dial_pattern`,`timegroup`),
  KEY `index` (`rate_deck_id`,`dial_pattern`,`timegroup`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `callaccounting_rate_patterns`
--

LOCK TABLES `callaccounting_rate_patterns` WRITE;
/*!40000 ALTER TABLE `callaccounting_rate_patterns` DISABLE KEYS */;
/*!40000 ALTER TABLE `callaccounting_rate_patterns` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `callaccounting_decks_trunks`
--

DROP TABLE IF EXISTS `callaccounting_decks_trunks`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `callaccounting_decks_trunks` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `rate_deck_id` int(11) NOT NULL,
  `trunk_id` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `index` (`rate_deck_id`,`trunk_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `callaccounting_decks_trunks`
--

LOCK TABLES `callaccounting_decks_trunks` WRITE;
/*!40000 ALTER TABLE `callaccounting_decks_trunks` DISABLE KEYS */;
/*!40000 ALTER TABLE `callaccounting_decks_trunks` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `callaccounting_cdr`
--

DROP TABLE IF EXISTS `callaccounting_cdr`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `callaccounting_cdr` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `calldate` datetime NOT NULL,
  `uniqueid` varchar(30) NOT NULL,
  `groupname` varchar(30) NOT NULL,
  `username` varchar(30) NOT NULL,
  `rate_deck_id` varchar(20) NOT NULL,
  `rate_pattern_id` varchar(20) NOT NULL,
  `destination` varchar(20) NOT NULL,
  `source` varchar(20) NOT NULL,
  `duration` varchar(10) NOT NULL,
  `billsec` varchar(10) NOT NULL,
  `cost` decimal(5,2) NOT NULL DEFAULT 0.00,
  `call_direction` varchar(15) NOT NULL,
  `tagname` varchar(20) NOT NULL,
  `comments` varchar(100) NOT NULL,
  `outcid` varchar(100) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `index1` (`username`,`uniqueid`,`calldate`,`rate_deck_id`,`groupname`,`source`,`destination`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `callaccounting_cdr`
--

LOCK TABLES `callaccounting_cdr` WRITE;
/*!40000 ALTER TABLE `callaccounting_cdr` DISABLE KEYS */;
/*!40000 ALTER TABLE `callaccounting_cdr` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2025-10-25  1:45:08

==> 20251101-010103-1761984063-16.0.41.1-481710196.tar.gz: files/tmp/callaccounting_dump/callaccounting.sql <==
-- MySQL dump 10.14  Distrib 5.5.65-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: asterisk
-- ------------------------------------------------------
-- Server version	5.5.65-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `callaccounting_ratedeck`
--

DROP TABLE IF EXISTS `callaccounting_ratedeck`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `callaccounting_ratedeck` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(30) COLLATE utf8mb4_unicode_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `index1` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `callaccounting_ratedeck`
--

LOCK TABLES `callaccounting_ratedeck` WRITE;
/*!40000 ALTER TABLE `callaccounting_ratedeck` DISABLE KEYS */;
/*!40000 ALTER TABLE `callaccounting_ratedeck` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `callaccounting_rate_patterns`
--

DROP TABLE IF EXISTS `callaccounting_rate_patterns`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `callaccounting_rate_patterns` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `rate_deck_id` int(11) NOT NULL,
  `dial_pattern` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL,
  `initial_cost` decimal(5,2) NOT NULL,
  `initial_time` varchar(5) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '0',
  `cost_per_increment` decimal(5,2) NOT NULL,
  `increment_time` varchar(5) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '60',
  `tagname` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `timegroup` int(11) DEFAULT NULL,
  `call_direction` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT 'Outbound',
  `add_time` datetime NOT NULL,
  `update_time` datetime NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `index1` (`rate_deck_id`,`dial_pattern`,`timegroup`),
  KEY `index` (`rate_deck_id`,`dial_pattern`,`timegroup`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `callaccounting_rate_patterns`
--

LOCK TABLES `callaccounting_rate_patterns` WRITE;
/*!40000 ALTER TABLE `callaccounting_rate_patterns` DISABLE KEYS */;
/*!40000 ALTER TABLE `callaccounting_rate_patterns` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `callaccounting_decks_trunks`
--

DROP TABLE IF EXISTS `callaccounting_decks_trunks`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `callaccounting_decks_trunks` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `rate_deck_id` int(11) NOT NULL,
  `trunk_id` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `index` (`rate_deck_id`,`trunk_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `callaccounting_decks_trunks`
--

LOCK TABLES `callaccounting_decks_trunks` WRITE;
/*!40000 ALTER TABLE `callaccounting_decks_trunks` DISABLE KEYS */;
/*!40000 ALTER TABLE `callaccounting_decks_trunks` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `callaccounting_cdr`
--

DROP TABLE IF EXISTS `callaccounting_cdr`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `callaccounting_cdr` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `calldate` datetime NOT NULL,
  `uniqueid` varchar(30) COLLATE utf8mb4_unicode_ci NOT NULL,
  `groupname` varchar(30) COLLATE utf8mb4_unicode_ci NOT NULL,
  `username` varchar(30) COLLATE utf8mb4_unicode_ci NOT NULL,
  `rate_deck_id` varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL,
  `rate_pattern_id` varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL,
  `destination` varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL,
  `source` varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL,
  `duration` varchar(10) COLLATE utf8mb4_unicode_ci NOT NULL,
  `billsec` varchar(10) COLLATE utf8mb4_unicode_ci NOT NULL,
  `cost` decimal(5,2) NOT NULL DEFAULT '0.00',
  `call_direction` varchar(15) COLLATE utf8mb4_unicode_ci NOT NULL,
  `tagname` varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL,
  `comments` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  `outcid` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  PRIMARY KEY (`id`),
  KEY `index1` (`username`,`uniqueid`,`calldate`,`rate_deck_id`,`groupname`,`source`,`destination`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `callaccounting_cdr`
--

LOCK TABLES `callaccounting_cdr` WRITE;
/*!40000 ALTER TABLE `callaccounting_cdr` DISABLE KEYS */;
/*!40000 ALTER TABLE `callaccounting_cdr` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2025-11-01  1:01:04
